@@ -87,13 +87,18 @@
 #include <assert.h>
 #include <errno.h>
 #include <locale.h>
+
 #ifndef _WIN32
+
 #include <langinfo.h>
 #define O_BINARY 0
+
 #ifdef HAVE_RECODE_H
 #define WITH_RECODE
 #endif
+
 #endif
+
 #ifdef WITH_RECODE
 #include <recode.h>
 #endif
@@ -111,7 +116,9 @@
 #ifdef DEBUG
 #define DPRINTF(l, x)                                                          \
     if (Debug >= l)                                                            \
-        fprintf x;
+    {                                                                          \
+        fprintf x;                                                             \
+    }
 #else
 #define DPRINTF(l, x)
 #endif
@@ -136,7 +143,6 @@ typedef struct fd
 
 static const char *env_lang = NULL;
 
-static bool Found_one = false;   /* did we find a match? */
 static bool Find_files = false;  /* just find a list of proper fortune files */
 static bool Wait = false;        /* wait desired after fortune */
 static bool Short_only = false;  /* short fortune desired */
@@ -163,11 +169,10 @@ static regex_t Re_pat;
 
 #ifdef WITH_REGEX
 static bool Match = false; /* dump fortunes matching a pattern */
-
 #endif
+
 #ifdef DEBUG
 static bool Debug = false; /* print debug messages */
-
 #endif
 
 static unsigned char *Fortbuf = NULL; /* fortune buffer for -m */
@@ -195,7 +200,7 @@ static inline char *my_recode_string(const char *s)
 static inline char *my_recode_string(const char *s) { return strdup(s); }
 #endif
 
-int add_dir(FILEDESC *);
+static int add_dir(FILEDESC *);
 
 static unsigned long my_random(const unsigned long base)
 {
@@ -222,7 +227,7 @@ static unsigned long my_random(const unsigned long base)
     fclose(fp);
     return l % base;
 fallback:
-    return random() % base;
+    return (((unsigned long)random()) % base);
 }
 
 static char *program_version(void)
@@ -284,24 +289,36 @@ static void print_list(FILEDESC *list, int lev)
     {
         fprintf(stderr, "%*s", lev * 4, "");
         if (list->percent == NO_PROB)
+        {
             if (!Equal_probs)
+            {
                 /* This, with some changes elsewhere, gives proper percentages
                  * for every case fprintf(stderr, "___%%"); */
                 fprintf(stderr, "%5.2f%%",
                     (100.0 - Spec_prob) * list->tbl.str_numstr /
                         Noprob_tbl.str_numstr);
+            }
             else if (lev == 0)
+            {
                 fprintf(stderr, "%5.2f%%", 100.0 / Num_files);
+            }
             else
+            {
                 fprintf(stderr, "%5.2f%%", 100.0 / Num_kids);
+            }
+        }
         else
+        {
             fprintf(stderr, "%5.2f%%", 1.0 * list->percent);
+        }
         fprintf(stderr, " %s", STR(list->name));
         DPRINTF(1, (stderr, " (%s, %s, %s)\n", STR(list->path),
                        STR(list->datfile), STR(list->posfile)));
         putc('\n', stderr);
         if (list->child)
+        {
             print_list(list->child, lev + 1);
+        }
         list = list->next;
     }
 }
@@ -311,19 +328,23 @@ static void print_list(FILEDESC *list, int lev)
  * conv_pat:
  *      Convert the pattern to an ignore-case equivalent.
  */
-static char *conv_pat(char *orig)
+static char *conv_pat(const char *const orig_str)
 {
-    char *sp;
+    const char *sp;
     char *new_buf;
 
     size_t cnt = 1; /* allow for '\0' */
-    for (sp = orig; *sp != '\0'; sp++)
+    for (sp = orig_str; *sp != '\0'; sp++)
     {
         const size_t prev_cnt = cnt;
         if (isalpha(*sp))
+        {
             cnt += 4;
+        }
         else
-            cnt++;
+        {
+            ++cnt;
+        }
         if (prev_cnt >= cnt)
         {
             fprintf(stderr, "%s",
@@ -337,26 +358,30 @@ static char *conv_pat(char *orig)
         exit(1);
     }
 
-    for (sp = new_buf; *orig != '\0'; orig++)
+    char *dest_ptr;
+    const char *orig = orig_str;
+    for (dest_ptr = new_buf; *orig != '\0'; ++orig)
     {
         if (islower(*orig))
         {
-            *sp++ = '[';
-            *sp++ = *orig;
-            *sp++ = (char)toupper(*orig);
-            *sp++ = ']';
+            *dest_ptr++ = '[';
+            *dest_ptr++ = *orig;
+            *dest_ptr++ = (char)toupper(*orig);
+            *dest_ptr++ = ']';
         }
         else if (isupper(*orig))
         {
-            *sp++ = '[';
-            *sp++ = *orig;
-            *sp++ = (char)tolower(*orig);
-            *sp++ = ']';
+            *dest_ptr++ = '[';
+            *dest_ptr++ = *orig;
+            *dest_ptr++ = (char)tolower(*orig);
+            *dest_ptr++ = ']';
         }
         else
-            *sp++ = *orig;
+        {
+            *dest_ptr++ = *orig;
+        }
     }
-    *sp = '\0';
+    *dest_ptr = '\0';
     return new_buf;
 }
 #endif
@@ -365,7 +390,7 @@ static char *conv_pat(char *orig)
  * do_malloc:
  *      Do a malloc, checking for NULL return.
  */
-static void *do_malloc(size_t size)
+static void *do_malloc(const size_t size)
 {
     void *new_buf = malloc(size);
 
@@ -385,7 +410,7 @@ static FILEDESC *new_fp(void)
 {
     FILEDESC *fp;
 
-    fp = (FILEDESC *)do_malloc(sizeof *fp);
+    fp = do_malloc(sizeof *fp);
     fp->datfd = -1;
     fp->pos = POS_UNKNOWN;
     fp->inf = NULL;
@@ -452,7 +477,9 @@ static int is_existant(char *file)
     struct stat staat;
 
     if (stat(file, &staat) == 0)
+    {
         return true;
+    }
     switch (errno)
     {
     case ENOENT:
@@ -481,9 +508,13 @@ static int is_fortfile(const char *const file, char **datp)
     DPRINTF(2, (stderr, "is_fortfile(%s) returns ", file));
 
     if (!sp)
+    {
         sp = file;
+    }
     else
+    {
         sp++;
+    }
     if (*sp == '.')
     {
         DPRINTF(2, (stderr, "%s", "false (file starts with '.')\n"));
@@ -493,11 +524,13 @@ static int is_fortfile(const char *const file, char **datp)
     {
         sp++;
         for (int i = 0; suflist[i]; ++i)
+        {
             if (strcmp(sp, suflist[i]) == 0)
             {
                 DPRINTF(2, (stderr, "false (file has suffix \".%s\")\n", sp));
                 return false;
             }
+        }
     }
 
     const size_t do_len = (strlen(file) + 6);
@@ -510,9 +543,13 @@ static int is_fortfile(const char *const file, char **datp)
         return false;
     }
     if (datp)
+    {
         *datp = datfile;
+    }
     else
+    {
         free(datfile);
+    }
     DPRINTF(2, (stderr, "%s", "true\n"));
     return true;
 }
@@ -531,10 +568,17 @@ static bool path_is_absolute(const char *const path)
 #endif
     return false;
 }
+
+static int open4read(const char *const path)
+{
+    return open(path, O_RDONLY | O_BINARY);
+}
+
 /*
  * add_file:
  *      Add a file to the file list.
  */
+#define GCC_SNPRINTF_MARGIN 10
 static int add_file(int percent, const char *file, const char *dir,
     FILEDESC **head, FILEDESC **tail, FILEDESC *parent)
 {
@@ -550,7 +594,8 @@ static int add_file(int percent, const char *file, const char *dir,
     }
     else
     {
-        const size_t do_len = (strlen(dir) + strlen(file) + 2);
+        const size_t do_len =
+            (strlen(dir) + strlen(file) + (2 + GCC_SNPRINTF_MARGIN));
         path = do_malloc(do_len + 1);
         snprintf(path, do_len, "%s/%s", dir, file);
     }
@@ -572,40 +617,12 @@ static int add_file(int percent, const char *file, const char *dir,
 #ifdef _WIN32
             (!isdir) &&
 #endif
-            ((fd = open(path, O_RDONLY | O_BINARY)) < 0)) ||
+            ((fd = open4read(path)) < 0)) ||
         !path_is_absolute(path))
     {
-        debugprint("sarahhhhh fd=%d path=<%s> dir=<%s> file=<%s> percent=%d\n",
+        debugprint("check file fd=%d path=<%s> dir=<%s> file=<%s> percent=%d\n",
             fd, path, dir, file, percent);
         bool found = false;
-        if (!dir && (!strchr(file, '/')))
-        {
-            if (((sp = strrchr(file, '-')) != NULL) && (strcmp(sp, "-o") == 0))
-            {
-#define CALL__add_file(dir) add_file(percent, file, dir, head, tail, parent)
-#define COND_CALL__add_file(loc_dir, dir)                                      \
-    ((!strcmp((loc_dir), (dir))) ? 0 : CALL__add_file(dir))
-                /* BSD-style '-o' offensive file suffix */
-                *sp = '\0';
-                found = CALL__add_file(LOCOFFDIR) ||
-                        COND_CALL__add_file(LOCOFFDIR, OFFDIR);
-                /* put the suffix back in for better identification later */
-                *sp = '-';
-            }
-            else if (All_forts)
-                found =
-                    (CALL__add_file(LOCFORTDIR) || CALL__add_file(LOCOFFDIR) ||
-                        COND_CALL__add_file(LOCFORTDIR, FORTDIR) ||
-                        COND_CALL__add_file(LOCOFFDIR, OFFDIR));
-            else if (Offend)
-                found = (CALL__add_file(LOCOFFDIR) ||
-                         COND_CALL__add_file(LOCOFFDIR, OFFDIR));
-            else
-                found = (CALL__add_file(LOCFORTDIR) ||
-                         COND_CALL__add_file(LOCFORTDIR, FORTDIR));
-#undef COND_CALL__add_file
-#undef CALL__add_file
-        }
         if (!found && !parent && !dir)
         { /* don't display an error when trying language specific files */
             if (env_lang)
@@ -623,24 +640,28 @@ static int add_file(int percent, const char *file, const char *dir,
                 {
                     char *p = strchr(lang, ':');
                     if (p)
+                    {
                         *p++ = '\0';
+                    }
                     snprintf(langdir, sizeof(langdir), "%s/%s", FORTDIR, lang);
 
                     if (strncmp(path, lang, 2) == 0)
+                    {
                         ret = 1;
+                    }
                     else if (strncmp(path, langdir, strlen(FORTDIR) + 3) == 0)
+                    {
                         ret = 1;
+                    }
                     lang = p;
                 }
                 if (!ret)
                 {
-                    debugprint("moshe\n");
                     perror(path);
                 }
             }
             else
             {
-                debugprint("abe\n");
                 perror(path);
             }
         }
@@ -666,7 +687,9 @@ static int add_file(int percent, const char *file, const char *dir,
     snprintf(testpath, do_len, "%s.u8", path);
     //    fprintf(stderr, "State mal: %s\n", testpath);
     if (stat(testpath, &statbuf) == 0)
+    {
         fp->utf8_charset = true;
+    }
 
     free(testpath);
     testpath = NULL;
@@ -677,8 +700,10 @@ static int add_file(int percent, const char *file, const char *dir,
     if ((isdir && !add_dir(fp)) || (!isdir && !is_fortfile(path, &fp->datfile)))
     {
         if (!parent)
+        {
             fprintf(
                 stderr, "fortune:%s not a fortune file or directory\n", path);
+        }
         free(path);
         path = NULL;
         free(fp->datfile);
@@ -686,7 +711,9 @@ static int add_file(int percent, const char *file, const char *dir,
         free(fp->name);
         free(fp->path);
         if (fp->fd >= 0)
+        {
             close(fp->fd);
+        }
         free(fp);
         return false;
     }
@@ -703,14 +730,18 @@ static int add_file(int percent, const char *file, const char *dir,
         free(fp->name);
         free(fp->path);
         if (fp->fd >= 0)
+        {
             close(fp->fd);
+        }
         free(fp);
         return true;
     }
     /* End hack. */
 
     if (!(*head))
+    {
         *head = *tail = fp;
+    }
     else if (fp->percent == NO_PROB)
     {
         (*tail)->next = fp;
@@ -738,7 +769,7 @@ static int names_compare(const void *a, const void *b)
  * add_dir:
  *      Add the contents of an entire directory.
  */
-int add_dir(FILEDESC *fp)
+static int add_dir(FILEDESC *const fp)
 {
     DIR *dir;
     struct dirent *dirent;
@@ -749,7 +780,6 @@ int add_dir(FILEDESC *fp)
     fp->fd = -1;
     if (!(dir = opendir(fp->path)))
     {
-        debugprint("yonah\n");
         perror(fp->path);
         return false;
     }
@@ -761,14 +791,15 @@ int add_dir(FILEDESC *fp)
     names = malloc(sizeof(names[0]) * max_count_names);
     if (!names)
     {
-        debugprint("zach\n");
         perror("Out of RAM!");
         exit(-1);
     }
     while ((dirent = readdir(dir)))
     {
         if (dirent->d_name[0] == 0)
+        {
             continue;
+        }
         char *name = strdup(dirent->d_name);
         if (count_names == max_count_names)
         {
@@ -776,7 +807,6 @@ int add_dir(FILEDESC *fp)
             names = realloc(names, sizeof(names[0]) * max_count_names);
             if (!names)
             {
-                debugprint("rebecca\n");
                 perror("Out of RAM!");
                 exit(-1);
             }
@@ -887,7 +917,9 @@ static int form_file_list(char **files, int file_cnt)
                 {
                     p = strchr(lang, ':');
                     if (p)
+                    {
                         *p++ = '\0';
+                    }
 
                     /* first try full locale */
                     ret = add_file(
@@ -906,7 +938,9 @@ static int form_file_list(char **files, int file_cnt)
 
                     /* if we have found one we have finished */
                     if (ret)
+                    {
                         return ret;
+                    }
                     lang = p;
                 }
                 /* default */
@@ -924,7 +958,9 @@ static int form_file_list(char **files, int file_cnt)
     {
         percent = NO_PROB;
         if (!isdigit(files[i][0]))
+        {
             sp = files[i];
+        }
         else
         {
             const int MAX_PERCENT = 100;
@@ -983,10 +1019,23 @@ static int form_file_list(char **files, int file_cnt)
                 sp = files[i];
             }
         }
+
+        /* BSD-style '-o' offensive file suffix */
+        bool offensive = false;
+        const size_t sp_len = strlen(sp);
+        if (sp_len >= 3 && sp[sp_len - 2] == '-' && sp[sp_len - 1] == 'o')
+        {
+            sp[sp_len - 2] = '\0';
+            offensive = true;
+        }
+
+        const char *fulldir = offensive ? OFFDIR : FORTDIR;
+        const char *locdir = offensive ? LOCOFFDIR : LOCFORTDIR;
+
         if (strcmp(sp, "all") == 0)
         {
-            snprintf(fullpathname, sizeof(fullpathname), "%s", FORTDIR);
-            snprintf(locpathname, sizeof(locpathname), "%s", LOCFORTDIR);
+            snprintf(fullpathname, sizeof(fullpathname), "%s", fulldir);
+            snprintf(locpathname, sizeof(locpathname), "%s", locdir);
         }
         /* if it isn't an absolute path or relative to . or ..
            make it an absolute path relative to FORTDIR */
@@ -996,9 +1045,8 @@ static int form_file_list(char **files, int file_cnt)
                 strncmp(sp, "../", 3) != 0)
             {
                 snprintf(
-                    fullpathname, sizeof(fullpathname), "%s/%s", FORTDIR, sp);
-                snprintf(
-                    locpathname, sizeof(locpathname), "%s/%s", LOCFORTDIR, sp);
+                    fullpathname, sizeof(fullpathname), "%s/%s", fulldir, sp);
+                snprintf(locpathname, sizeof(locpathname), "%s/%s", locdir, sp);
             }
             else
             {
@@ -1021,11 +1069,13 @@ static int form_file_list(char **files, int file_cnt)
             {
                 char *p = strchr(lang, ':');
                 if (p)
+                {
                     *p++ = '\0';
+                }
 
                 /* first try full locale */
                 snprintf(
-                    langdir, sizeof(langdir), "%s/%s/%s", FORTDIR, lang, sp);
+                    langdir, sizeof(langdir), "%s/%s/%s", fulldir, lang, sp);
                 ret = add_file(
                     percent, langdir, NULL, &File_list, &File_tail, NULL);
 
@@ -1037,7 +1087,7 @@ static int form_file_list(char **files, int file_cnt)
                     strncpy(ll, lang, 2);
                     ll[2] = '\0';
                     snprintf(
-                        langdir, sizeof(langdir), "%s/%s/%s", FORTDIR, ll, sp);
+                        langdir, sizeof(langdir), "%s/%s/%s", fulldir, ll, sp);
                     ret = add_file(
                         percent, langdir, NULL, &File_list, &File_tail, NULL);
                 }
@@ -1046,15 +1096,29 @@ static int form_file_list(char **files, int file_cnt)
             }
             /* default */
             if (!ret)
+            {
                 ret = add_file(
                     percent, fullpathname, NULL, &File_list, &File_tail, NULL);
+            }
             if (!ret &&
                 strncmp(fullpathname, locpathname, sizeof(fullpathname)))
+            {
                 ret = add_file(
                     percent, locpathname, NULL, &File_list, &File_tail, NULL);
-
+            }
+            if (strncmp(fullpathname, locpathname, sizeof(fullpathname)) &&
+                strcmp(sp, "all") == 0)
+            {
+                add_file(
+                    percent, locpathname, NULL, &File_list, &File_tail, NULL);
+            }
             if (!ret)
             {
+                if (offensive)
+                {
+                    // restore -o suffix
+                    sp[sp_len - 2] = '-';
+                }
                 snprintf(locpathname, sizeof(locpathname), "%s/%s",
                     getenv("PWD"), sp);
 
@@ -1065,16 +1129,12 @@ static int form_file_list(char **files, int file_cnt)
             {
                 return false;
             }
-            if (strncmp(fullpathname, locpathname, sizeof(fullpathname)) &&
-                strcmp(sp, "all") == 0)
-            {
-                add_file(
-                    percent, locpathname, NULL, &File_list, &File_tail, NULL);
-            }
         }
         else if (!add_file(
                      percent, fullpathname, NULL, &File_list, &File_tail, NULL))
+        {
             return false;
+        }
     }
     return true;
 }
@@ -1084,9 +1144,8 @@ static int form_file_list(char **files, int file_cnt)
  */
 static void getargs(int argc, char **argv)
 {
-    bool ignore_case = false;
-
 #ifdef WITH_REGEX
+    bool ignore_case = false;
     char *pat = NULL;
 #endif
 
@@ -1098,14 +1157,11 @@ static void getargs(int argc, char **argv)
 #define DEBUG_GETOPT
 #endif
 
-#ifdef NO_OFFENSIVE
-#define OFFENSIVE_GETOPT
-#else
 #define OFFENSIVE_GETOPT "o"
-#endif
 
     while ((ch = getopt(argc, argv,
-                "ac" DEBUG_GETOPT "efilm:n:" OFFENSIVE_GETOPT "suvw")) != EOF)
+                "ac" DEBUG_GETOPT "efhilm:n:" OFFENSIVE_GETOPT "suvw")) != EOF)
+    {
         switch (ch)
         {
         case 'a': /* any fortune */
@@ -1129,11 +1185,17 @@ static void getargs(int argc, char **argv)
         case 'n':
             SLEN = atoi(optarg);
             break;
-#ifndef NO_OFFENSIVE
         case 'o': /* offensive ones only */
+#ifndef NO_OFFENSIVE
             Offend = true;
-            break;
+#else
+            (void)fprintf(stderr, "%s",
+                "fortune: this fortune was built with -D NO_OFFENSIVE=1"
+                " so the -o flag is unavailable "
+                "(Sorry)\n");
+            exit(1);
 #endif
+            break;
         case 's': /* short ones only */
             Short_only = true;
             Long_only = false;
@@ -1145,16 +1207,17 @@ static void getargs(int argc, char **argv)
         case 'i': /* case-insensitive match */
         case 'm': /* dump out the fortunes */
             (void)fprintf(stderr, "%s",
-                "fortune: can't match fortunes on this system (Sorry)\n");
+                "fortune: can't match fortunes on this system "
+                "(Sorry)\n");
             exit(0);
 #else             /* NO_REGEX */
+        case 'i': /* case-insensitive match */
+            ignore_case = true;
+            break;
         case 'm': /* dump out the fortunes */
             Match = true;
             pat = optarg;
             break;
-        case 'i': /* case-insensitive match */
-            ignore_case = true;
-            break;
 #endif            /* NO_REGEX */
         case 'u': /* Don't recode the fortune */
             No_recode = true;
@@ -1165,10 +1228,12 @@ static void getargs(int argc, char **argv)
         case 'c':
             Show_filename = true;
             break;
+        case 'h':
         case '?':
         default:
             usage();
         }
+    }
     argc -= optind;
     argv += optind;
 
@@ -1181,16 +1246,21 @@ static void getargs(int argc, char **argv)
         exit(1); /* errors printed through form_file_list() */
     }
 #ifdef DEBUG
-/*      if (Debug >= 1)
- * print_list(File_list, 0); */
-#endif /* DEBUG */
+#if 0
+      if (Debug >= 1)
+ print_list(File_list, 0); /* Causes crash with new %% code */
+
+#endif
+#endif
 
 /* If (Find_files) print_list() moved to main */
 #ifdef WITH_REGEX
     if (pat)
     {
         if (ignore_case)
+        {
             pat = conv_pat(pat);
+        }
         if (BAD_COMP(RE_COMP(pat)))
         {
             fprintf(stderr, "bad pattern: %s\n", pat);
@@ -1220,14 +1290,20 @@ static void init_prob(void)
      */
     FILEDESC *last = NULL;
     for (fp = File_tail; fp; fp = fp->prev)
+    {
         if (fp->percent == NO_PROB)
         {
             num_noprob++;
             if (Equal_probs)
+            {
                 last = fp;
+            }
         }
         else
+        {
             percent += fp->percent;
+        }
+    }
     DPRINTF(1, (stderr, "summing probabilities:%d%% with %d NO_PROB's\n",
                    percent, num_noprob));
     if (percent > 100)
@@ -1238,16 +1314,19 @@ static void init_prob(void)
     else if (percent < 100 && num_noprob == 0)
     {
         fprintf(stderr,
-            "fortune: no place to put residual probability (%d%%)\n", percent);
+            "fortune: no place to put residual probability "
+            "(%d%%)\n",
+            percent);
         exit(1);
     }
     else if (percent == 100 && num_noprob != 0)
     {
-        fprintf(
-            stderr, "fortune: no probability left to put in residual files\n");
+        fprintf(stderr, "fortune: no probability left to put in "
+                        "residual files\n");
         exit(1);
     }
-    Spec_prob = percent; /* this is for -f when % is specified on cmd line */
+    Spec_prob = percent; /* this is for -f when % is specified on
+                            cmd line */
     percent = 100 - percent;
     if (Equal_probs)
     {
@@ -1258,11 +1337,13 @@ static void init_prob(void)
                 frac = percent / num_noprob;
                 DPRINTF(1, (stderr, ", frac = %d%%", frac));
                 for (fp = File_tail; fp != last; fp = fp->prev)
+                {
                     if (fp->percent == NO_PROB)
                     {
                         fp->percent = frac;
                         percent -= frac;
                     }
+                }
             }
             last->percent = percent;
             DPRINTF(1, (stderr, ", residual = %d%%", percent));
@@ -1276,8 +1357,13 @@ static void init_prob(void)
     DPRINTF(1, (stderr, "%s", "\n"));
 
 #ifdef DEBUG
-/*      if (Debug >= 1)
- * print_list(File_list, 0); *//* Causes crash with new %% code */
+#if 0
+      if (Debug >= 1)
+    {
+ print_list(File_list, 0); /* Causes crash with new %% code */
+    }
+
+#endif
 #endif
 }
 
@@ -1300,9 +1386,13 @@ static void sum_tbl(STRFILE *t1, STRFILE *t2)
 {
     t1->str_numstr += t2->str_numstr;
     if (t1->str_longlen < t2->str_longlen)
+    {
         t1->str_longlen = t2->str_longlen;
+    }
     if (t1->str_shortlen > t2->str_shortlen)
+    {
         t1->str_shortlen = t2->str_shortlen;
+    }
 }
 
 /*
@@ -1315,10 +1405,12 @@ static void get_tbl(FILEDESC *fp)
     FILEDESC *child;
 
     if (fp->read_tbl)
+    {
         return;
+    }
     if (!(fp->child))
     {
-        if ((fd = open(fp->datfile, O_RDONLY | O_BINARY)) < 0)
+        if ((fd = open4read(fp->datfile)) < 0)
         {
             perror(fp->datfile);
             exit(1);
@@ -1387,15 +1479,19 @@ static void sum_noprobs(FILEDESC *fp)
     static bool did_noprobs = false;
 
     if (did_noprobs)
+    {
         return;
+    }
     zero_tbl(&Noprob_tbl);
     while (fp)
     {
         get_tbl(fp);
-        /* This conditional should help us return correct values for -f
-         * when a percentage is specified */
+        /* This conditional should help us return correct values for
+         * -f when a percentage is specified */
         if (fp->percent == NO_PROB)
+        {
             sum_tbl(&Noprob_tbl, &fp->tbl);
+        }
         fp = fp->next;
     }
     did_noprobs = true;
@@ -1412,11 +1508,13 @@ static FILEDESC *pick_child(FILEDESC *parent)
 
     if (Equal_probs)
     {
-        choice = my_random(parent->num_children);
+        choice = (int)my_random((unsigned long)parent->num_children);
         DPRINTF(1, (stderr, "    choice = %d (of %d)\n", choice,
                        parent->num_children));
         for (fp = parent->child; choice--; fp = fp->next)
+        {
             continue;
+        }
         DPRINTF(1, (stderr, "    using %s\n", fp->name));
         return fp;
     }
@@ -1445,8 +1543,7 @@ static FILEDESC *pick_child(FILEDESC *parent)
  */
 static void open_dat(FILEDESC *fp)
 {
-    if (fp->datfd < 0 &&
-        (fp->datfd = open(fp->datfile, O_RDONLY | O_BINARY)) < 0)
+    if (fp->datfd < 0 && (fp->datfd = open4read(fp->datfile)) < 0)
     {
         exit(1);
     }
@@ -1454,8 +1551,8 @@ static void open_dat(FILEDESC *fp)
 
 /*
  * get_pos:
- *      Get the position from the pos file, if there is one.  If not,
- *      return a random number.
+ *      Get the position from the pos file, if there is one.  If
+ * not, return a random number.
  */
 static void get_pos(FILEDESC *fp)
 {
@@ -1465,13 +1562,16 @@ static void get_pos(FILEDESC *fp)
         fp->pos = (int32_t)(my_random(fp->tbl.str_numstr));
     }
     if (++(fp->pos) >= (int32_t)fp->tbl.str_numstr)
+    {
         fp->pos -= fp->tbl.str_numstr;
+    }
     DPRINTF(1, (stderr, "pos for %s is %ld\n", fp->name, fp->pos));
 }
 
 /*
  * get_fort:
- *      Get the fortune data file's seek pointer for the next fortune.
+ *      Get the fortune data file's seek pointer for the next
+ * fortune.
  */
 static void get_fort(void)
 {
@@ -1479,25 +1579,33 @@ static void get_fort(void)
     int choice;
 
     if (!File_list->next || File_list->percent == NO_PROB)
+    {
         fp = File_list;
+    }
     else
     {
-        choice = my_random(100);
+        choice = (int)my_random(100);
         DPRINTF(1, (stderr, "choice = %d\n", choice));
         for (fp = File_list; fp->percent != NO_PROB; fp = fp->next)
+        {
             if (choice < fp->percent)
+            {
                 break;
+            }
             else
             {
                 choice -= fp->percent;
                 DPRINTF(1, (stderr, "    skip \"%s\", %d%% (choice = %d)\n",
                                fp->name, fp->percent, choice));
             }
+        }
         DPRINTF(1, (stderr, "using \"%s\", %d%% (choice = %d)\n", fp->name,
                        fp->percent, choice));
     }
     if (fp->percent != NO_PROB)
+    {
         get_tbl(fp);
+    }
     else
     {
         if (fp->next)
@@ -1570,7 +1678,9 @@ static int maxlen_in_list(FILEDESC *list)
         if (fp->child)
         {
             if ((len = maxlen_in_list(fp->child)) > maxlen)
+            {
                 maxlen = len;
+            }
         }
         else
         {
@@ -1588,7 +1698,7 @@ static int maxlen_in_list(FILEDESC *list)
  * matches_in_list
  *      Print out the matches from the files in the list.
  */
-static void matches_in_list(FILEDESC *list)
+static void matches_in_list(FILEDESC *list, bool *const Found_one_ptr)
 {
     unsigned char *sp;
     unsigned char *p; /* -allover */
@@ -1601,7 +1711,7 @@ static void matches_in_list(FILEDESC *list)
     {
         if (fp->child)
         {
-            matches_in_list(fp->child);
+            matches_in_list(fp->child, Found_one_ptr);
             continue;
         }
         DPRINTF(1, (stderr, "searching in %s\n", fp->path));
@@ -1634,9 +1744,13 @@ static void matches_in_list(FILEDESC *list)
                     for (p = (unsigned char *)output; (ch = *p); ++p)
                     {
                         if (isupper(ch) && isascii(ch))
+                        {
                             *p = 'A' + (ch - 'A' + 13) % 26;
+                        }
                         else if (islower(ch) && isascii(ch))
+                        {
                             *p = 'a' + (ch - 'a' + 13) % 26;
+                        }
                     }
                 }
 
@@ -1648,7 +1762,7 @@ static void matches_in_list(FILEDESC *list)
                     {
                         fprintf(
                             stderr, "(%s)\n%c\n", fp->name, fp->tbl.str_delim);
-                        Found_one = true;
+                        (*Found_one_ptr) = true;
                         in_file = true;
                     }
                     fputs(output, stdout);
@@ -1669,17 +1783,18 @@ static void matches_in_list(FILEDESC *list)
 
 /*
  * find_matches:
- *      Find all the fortunes which match the pattern we've been given.
+ *      Find all the fortunes which match the pattern we've been
+ * given.
  */
-static int find_matches(void)
+static bool find_matches(void)
 {
     Fort_len = maxlen_in_list(File_list);
     DPRINTF(2, (stderr, "Maximum length is %d\n", Fort_len));
     /* extra length, "%\n" is appended */
     Fortbuf = do_malloc((unsigned int)Fort_len + 10);
 
-    Found_one = false;
-    matches_in_list(File_list);
+    bool Found_one = false;
+    matches_in_list(File_list, &Found_one);
     return Found_one;
     /* NOTREACHED */
 }
@@ -1693,7 +1808,9 @@ static void display(FILEDESC *fp)
     open_fp(fp);
     fseek(fp->inf, (long)Seekpts[0], SEEK_SET);
     if (Show_filename)
+    {
         printf("(%s)\n%%\n", fp->name);
+    }
     for (Fort_len = 0; fgets((char *)line, sizeof line, fp->inf) &&
                        !STR_ENDSTRING(line, fp->tbl);
          Fort_len++)
@@ -1703,9 +1820,13 @@ static void display(FILEDESC *fp)
             for (p = (char *)line; (ch = *p); ++p)
             {
                 if (isupper(ch) && isascii(ch))
+                {
                     *p = 'A' + (ch - 'A' + 13) % 26;
+                }
                 else if (islower(ch) && isascii(ch))
+                {
                     *p = 'a' + (ch - 'a' + 13) % 26;
+                }
             }
         }
         if (fp->utf8_charset && (!No_recode))
@@ -1730,7 +1851,9 @@ static int fortlen(void)
     char line[BUFSIZ];
 
     if (!(Fortfile->tbl.str_flags & (STR_RANDOM | STR_ORDERED)))
+    {
         nchar = (Seekpts[1] - Seekpts[0]) - 2; /* for %^J delimiter */
+    }
     else
     {
         open_fp(Fortfile);
@@ -1738,7 +1861,9 @@ static int fortlen(void)
         nchar = 0;
         while (fgets(line, sizeof line, Fortfile->inf) &&
                !STR_ENDSTRING(line, Fortfile->tbl))
+        {
             nchar += strlen(line);
+        }
     }
     Fort_len = nchar;
     return nchar;
@@ -1766,7 +1891,7 @@ static void free_desc(FILEDESC *ptr)
     }
 }
 
-int main(int ac, char *av[])
+int main(int argc, char *argv[])
 {
 #ifdef WITH_RECODE
     const char *ctype;
@@ -1775,11 +1900,17 @@ int main(int ac, char *av[])
     int exit_code = 0;
     env_lang = getenv("LC_ALL");
     if (!env_lang)
+    {
         env_lang = getenv("LC_MESSAGES");
+    }
     if (!env_lang)
+    {
         env_lang = getenv("LANGUAGE");
+    }
     if (!env_lang)
+    {
         env_lang = getenv("LANG");
+    }
 #ifdef _WIN32
     if (!env_lang)
     {
@@ -1787,10 +1918,7 @@ int main(int ac, char *av[])
     }
 #endif
 
-#ifndef DONT_CALL_GETARGS
-    getargs(ac, av);
-#endif
-
+    getargs(argc, argv);
 #ifdef WITH_RECODE
     outer = recode_new_outer(true);
     request = recode_new_request(outer);
@@ -1812,7 +1940,7 @@ int main(int ac, char *av[])
         ctype = "ISO-8859-1";
     }
 #endif
-    const size_t do_len = strlen(ctype) + 7 + 1;
+    const size_t do_len = strlen(ctype) + (7 + 1 + GCC_SNPRINTF_MARGIN);
     char *crequest = do_malloc(do_len + 1);
     snprintf(crequest, do_len, "UTF-8..%s", ctype);
     recode_scan_request(request, crequest);
@@ -1822,7 +1950,7 @@ int main(int ac, char *av[])
 #ifdef WITH_REGEX
     if (Match)
     {
-        exit_code = (find_matches() != 0);
+        exit_code = find_matches();
         regfree(&Re_pat);
         goto cleanup;
     }
@@ -1833,12 +1961,14 @@ int main(int ac, char *av[])
     {
         sum_noprobs(File_list);
         if (Equal_probs)
+        {
             calc_equal_probs();
+        }
         print_list(File_list, 0);
     }
     else
     {
-        srandom((unsigned int)(time((time_t *)NULL) + getpid()));
+        call_srandom();
         do
         {
             get_fort();
@@ -1853,7 +1983,10 @@ int main(int ac, char *av[])
             sleep((unsigned int)mymax(Fort_len / CPERS, MINW));
         }
     }
+#ifdef WITH_REGEX
 cleanup:
+#endif
+
 #ifdef WITH_RECODE
     recode_delete_request(request);
     recode_delete_outer(outer);
